import { defineConfig } from 'rollup';
//打包时排除 peer dependencies，减小组件库的体积
import peerDepsExternal from 'rollup-plugin-peer-deps-external';
//打包第三方依赖模块
import resolve from '@rollup/plugin-node-resolve';
//转换为 CommonJS (CJS) 格式
import commonjs from '@rollup/plugin-commonjs';
//将 TypeScript 文件转换为 JavaScript。
//设置 "useTsconfigDeclarationDir": true 输出指定目录的 .d.ts 文件
import typescript from 'rollup-plugin-typescript2';
//缩小生成的 es 包
import { terser } from 'rollup-plugin-terser';
import { DEFAULT_EXTENSIONS } from '@babel/core';
import postcss from 'rollup-plugin-postcss';
import NpmImport from 'less-plugin-npm-import';
import babel from '@rollup/plugin-babel';
import typescriptEngine from 'typescript';

export default defineConfig({
  input: './src/index.ts',
  output: [
    {
      file: 'dist/bundle.es.js',
      format: 'esm',
    },
    {
      file: 'dist/bundle.js',
      format: 'cjs',
    },
  ],
  plugins: [
    postcss({
      extensions: ['.css'],
      extract: true,
      modules: true,
      minimize: true,
      autoModules: false,
      use: [['less', { plugins: [new NpmImport({ prefix: '~' })] }]],
    }),
    peerDepsExternal(),
    typescript({
      useTsconfigDeclarationDir: true,
      typescript: typescriptEngine,
      include: ['*.js+(|x)', '**/*.js+(|x)'],
      exclude: [
        'coverage',
        'config',
        'dist',
        'node_modules/**',
        '*.test.{js+(|x), ts+(|x)}',
        '**/*.test.{js+(|x), ts+(|x)}',
      ],
    }),
    resolve(),
    commonjs({
      sourceMap: false,
    }),
    babel({
      extensions: [...DEFAULT_EXTENSIONS, '.ts', 'tsx'],
      babelHelpers: 'bundled',
    }),
    terser(),
  ],
  watch: {
    exclude: 'node_modules/**',
  },
  external: ['react', 'react-dom', '@babel/runtime', 'less'],
});
